import { ChartAnnotation, ChartDimension, ChartMeasure, ChartSettings, EntityType, Property, QueryReturn } from '@metad/ocap-core';
import { AxisEnum, EChartsOptions, ICoordinate, SeriesComponentType } from './types';
export declare function cartesian(data: QueryReturn<unknown>, chartAnnotation: ChartAnnotation, entityType: EntityType, settings: ChartSettings, options: EChartsOptions, type: string): {
    dataset: any[];
    title: any[];
    grid: any[];
    xAxis: any[];
    yAxis: any[];
    series: any[];
    visualMap: any[];
    tooltip: any[];
    legend: any[];
    dataZoom: any[];
};
/**
 * 单个笛卡尔坐标系, 对应一个 grid 内的组件
 *
 * @param data 数据数组
 * @param chartAnnotation 图形注解
 * @param entityType 实体类型
 * @param settings 图形设置
 * @param options 图形属性
 * @returns
 */
export declare function cartesianCoordinate(data: Array<Record<string, unknown>>, chartAnnotation: ChartAnnotation, entityType: EntityType, settings: ChartSettings, options: EChartsOptions): ICoordinate;
export declare function serializeSeriesComponent(dataset: any, seriesComponent: SeriesComponentType, entityType: any, category: any, valueAxis: any, settings: ChartSettings, options: EChartsOptions): {
    series: any;
    visualMaps: any[];
};
export declare function getVisualMapValueAxisIndex(dataset: any, seriesComponent: any, series?: ChartDimension): any;
export declare function getLegendColorForVisualMap(colors: any): any;
export declare function getSymbolSizeVisualMap(measure: ChartMeasure, property: Property, dataset: any): {
    left: string;
    top: string;
    dimension: any;
    itemWidth: number;
    itemHeight: number;
    calculable: boolean;
    precision: number;
    text: string[];
    textGap: number;
    inRange: {
        symbolSize: number[];
    };
    outOfRange: {
        symbolSize: number[];
        color: string[];
    };
    controller: {
        inRange: {
            color: string[];
        };
        outOfRange: {
            color: string[];
        };
    };
};
export declare function getColorLightnessVisualMap(measure: ChartMeasure, property: Property, dataset: {
    dimensions: string[];
    source: any;
}): {
    left: string;
    bottom: string;
    dimension: string | number;
    itemHeight: number;
    text: string[];
    textGap: number;
    inRange: {
        colorLightness: number[];
    };
    outOfRange: {
        color: string[];
    };
    controller: {
        inRange: {
            color: string[];
        };
        outOfRange: {
            color: string[];
        };
    };
};
export declare function measuresToSeriesComponents(measures: ChartMeasure[], data: any[], entityType: EntityType, settings: ChartSettings): SeriesComponentType[];
export declare function dimensionToSeriesComponent(name: string, dimension: ChartDimension, measures: ChartMeasure[], data: any[], entityType: EntityType, settings: ChartSettings): SeriesComponentType;
/**
 *
 * @param chartAnnotation
 * @param entityType
 * @param items
 * @param chartOptions
 * @param locale
 * @returns
 */
export declare function getCoordinateSystem(chartAnnotation: ChartAnnotation, entityType: EntityType, items: Array<unknown>, chartOptions: EChartsOptions, locale?: string): {
    categoryAxis: {
        orient: AxisEnum;
        axis: any[];
    };
    valueAxis: {
        orient: AxisEnum;
        axis: any;
    };
};
